# DudeSecurity - Python
[![Build Status](https://travis-ci.org/joemccann/dillinger.svg?branch=master)](https://test.pypi.org/project/dudesec)


O projeto Dude tem como objetivo a criação de uma library para python ligado a segurança cibernética e monitoramento de servidores e estações datrabalho.
Neste repositório, iremos abranger os seguintes objetivos:

  - Segurança e monitoramento de redes.
  - Segurança e monitoramento de servidores.
  - Segurança e monitoramento de aplicações.
  - Segurança de estações de trabalho e computadores pessoais.

Para acompanhar a library, usamos a seguinte lógica: Na branch master, estará presente a versão mais atual. Nas outras branchs, estarão disponibilizadas o código de acordo com a versão.

# Ferramentas presentes na versão atual:

  - Scanner de portas abertas a partir de um range pré definido.
  - Monitoramento de aplicações WEB através de webscrapping.
  - Monitoramento de dominios.
  - Monitoramento de aplicações APIS.
  - Implementação de WEBHOOK para atualizações.
  - Codificação e decodificação de textos usando base64.
  - Varredura de portas para exploração de vunerabilidades.
  - Gerador de WorldList para ataques brute-force.

> Lembrando que, o repositório está e sempre estará aberto a novas opiniões
> e ponto de vista. Portanto, ao requisitar alguma atualização lembre-se
> que esta lib é uma ajuda, não um direito tenha educação e simpatia.

# Ideias para possiveis atualizações:

- Captura de tela de website por webscrapping

### Como instalar

Para usar esta library com o Python é bem simples, basta instala-la usando o gerenciador de pacotes pipy , com o seguinte comando:

```sh
$ pip install dudsec
```

E após isto, importa-lo desta maneira:

```sh
import * from dudesec
```
### Nossa comunidade & documentação

Comunidade: https://dudeproject.online
